==> aioamqp_consumer-0.1.2.tar.gz: aioamqp_consumer-0.1.2/setup.py <==
import io
import os
import re

from setuptools import setup


def get_version():
    regex = r"__version__\s=\s\'(?P<version>[\d\.]+?)\'"

    path = ('aioamqp_consumer', '__init__.py')

    return re.search(regex, read(*path)).group('version')


def read(*parts):
    filename = os.path.join(os.path.abspath(os.path.dirname(__file__)), *parts)

    with io.open(filename, encoding='utf-8', mode='rt') as fp:
        return fp.read()


setup(
    name='aioamqp_consumer',
    version=get_version(),
    author='OCEAN S.A.',
    author_email='osf@ocean.io',
    url='https://github.com/wikibusiness/aioamqp_consumer',
    description='Consumer/producer like library built over amqp (aioamqp)',
    long_description=read('README.rst'),
    python_requires='>=3.5.2',
    install_requires=[
        'aioamqp>=0.10.0',
        'async_timeout>=2.0.0',
    ],
    packages=['aioamqp_consumer'],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords=['aioamqp', 'amqp', 'asyncio', 'consumer', 'producer'],
)

==> aioamqp_consumer-0.2.0.tar.gz: aioamqp_consumer-0.2.0/setup.py <==
import io
import os
import re

from setuptools import setup


def get_version():
    regex = r"__version__\s=\s\'(?P<version>[\d\.]+?)\'"

    path = ('aioamqp_consumer', '__init__.py')

    return re.search(regex, read(*path)).group('version')


def read(*parts):
    filename = os.path.join(os.path.abspath(os.path.dirname(__file__)), *parts)

    with io.open(filename, encoding='utf-8', mode='rt') as fp:
        return fp.read()


setup(
    name='aioamqp_consumer',
    version=get_version(),
    author='OCEAN S.A.',
    author_email='hellysmile@gmail.com',
    url='https://github.com/aio-libs/aioamqp_consumer',
    description='consumer/producer/rpc library built over aioamqp',
    long_description=read('README.rst'),
    python_requires='>=3.6.0',
    install_requires=[
        'aioamqp>=0.14.0',
        'async_timeout>=3.0.0',
    ],
    packages=['aioamqp_consumer'],
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    keywords=['amqp', 'asyncio', 'aioamqp', 'consumer', 'producer', 'rpc'],
)
